utils

package
v0.0.0-...-a82fcff Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitTracer

func InitTracer() func()

InitTracer initializes a new OpenTelemetry tracer with a stdout exporter that prints trace data in a human-readable format. It returns a function that can be called to shut down the tracer provider and clean up resources.

Usage:

cleanup := InitTracer()
defer cleanup()

Returns:

A function that shuts down the tracer provider when called.

Types

This section is empty.

Jump to