Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitTracer ¶
func InitTracer() func()
InitTracer initializes a new OpenTelemetry tracer with a stdout exporter that prints trace data in a human-readable format. It returns a function that can be called to shut down the tracer provider and clean up resources.
Usage:
cleanup := InitTracer() defer cleanup()
Returns:
A function that shuts down the tracer provider when called.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.